package me.nvus.nvus_prison_setup.Configs;

import org.bukkit.Bukkit;
import org.bukkit.ChatColor;
import org.bukkit.Material;
import org.bukkit.configuration.file.FileConfiguration;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.inventory.InventoryClickEvent;
import org.bukkit.inventory.Inventory;
import org.bukkit.inventory.ItemStack;
import org.bukkit.inventory.meta.ItemMeta;
import org.bukkit.plugin.java.JavaPlugin;

public class SettingsMenu implements Listener {
    private final ConfigManager configManager;

    public SettingsMenu(JavaPlugin plugin, ConfigManager configManager) {
        this.configManager = configManager;
        plugin.getServer().getPluginManager().registerEvents(this, plugin);
    }

    public void openSettingsMenu(Player player) {
        Inventory inv = Bukkit.createInventory(null, 9, ChatColor.DARK_GREEN + "Settings Menu");

        // Dynamically set the display based on current config settings
        FileConfiguration config = configManager.getConfig("config.yml");

        // AutoPickup Toggle Item
        boolean autopickup = config.getBoolean("AutoPickup", false);
        ItemStack toggleAutoPickup = createToggleItem(Material.HOPPER, "Toggle AutoPickup", autopickup);
        inv.setItem(3, toggleAutoPickup);

        // AutoSwitch Toggle Item
        boolean autoswitch = config.getBoolean("AutoSwitch", false);
        ItemStack toggleAutoSwitch = createToggleItem(Material.LEVER, "Toggle AutoSwitch", autoswitch);
        inv.setItem(4, toggleAutoSwitch);

        // Reload Configurations Item
        ItemStack reloadConfigs = new ItemStack(Material.BOOK);
        ItemMeta reloadMeta = reloadConfigs.getItemMeta();
        reloadMeta.setDisplayName(ChatColor.GREEN + "Reload Configs");
        reloadConfigs.setItemMeta(reloadMeta);
        inv.setItem(5, reloadConfigs);

        player.openInventory(inv);
    }

    private ItemStack createToggleItem(Material material, String name, boolean enabled) {
        ItemStack item = new ItemStack(material);
        ItemMeta meta = item.getItemMeta();
        meta.setDisplayName(ChatColor.GREEN + name + ": " + (enabled ? ChatColor.BLUE + "Enabled" : ChatColor.RED + "Disabled"));
        item.setItemMeta(meta);
        return item;
    }

    @EventHandler
    public void onInventoryClick(InventoryClickEvent event) {
        if (!event.getView().getTitle().equals(ChatColor.DARK_GREEN + "Settings Menu")) return;
        event.setCancelled(true);
        Player player = (Player) event.getWhoClicked();
        ItemStack clickedItem = event.getCurrentItem();
        if (clickedItem == null || !clickedItem.hasItemMeta()) return;

        String displayName = clickedItem.getItemMeta().getDisplayName();
        FileConfiguration config = configManager.getConfig("config.yml");

        if (displayName.contains("Toggle AutoPickup")) {
            boolean currentValue = config.getBoolean("AutoPickup", false);
            config.set("AutoPickup", !currentValue);
            player.sendMessage(ChatColor.GREEN + "AutoPickup " + (currentValue ? "disabled" : "enabled"));
        } else if (displayName.contains("Toggle AutoSwitch")) {
            boolean currentValue = config.getBoolean("AutoSwitch", false);
            config.set("AutoSwitch", !currentValue);
            player.sendMessage(ChatColor.GREEN + "AutoSwitch " + (currentValue ? "disabled" : "enabled"));
        } else if (displayName.contains("Reload Configs")) {
            configManager.reloadConfig("config.yml");
            configManager.reloadConfig("auto_switch.yml");
            configManager.reloadConfig("banned_items.yml");
            player.sendMessage(ChatColor.GREEN + "Configuration files reloaded.");
        }

        configManager.saveConfig("config.yml");
        player.closeInventory(); // Optional: Close the inventory after interaction
    }
}
